@@ -28,12 +28,10 @@ from dask.dataframe.optimize import optimize as dd_optimize
 from dask.distributed import Client, get_client
 from tqdm import tqdm
 
+from merlin.core.compat import HAS_GPU, cuda
+
 _merlin_dask_client = ContextVar("_merlin_dask_client", default="auto")
 
-try:
-    from numba import cuda
-except ImportError:
-    cuda = None
 
 try:
     import psutil
@@ -183,7 +181,7 @@ class Distributed:
     -----------
     client : `dask.distributed.Client`; Optional
         The client to use for distributed-Dask execution.
-    new_cluster : {"cuda", "cpu", None}
+    cluster_type : {"cuda", "cpu", None}
         Type of local cluster to generate in the case that a
         global client is not detected (or `force_new=True`).
         "cuda" corresponds to `dask_cuda.LocalCUDACluster`,
@@ -195,7 +193,7 @@ class Distributed:
         detected. Default is False.
     **cluster_options :
         Key-word arguments to pass to the local-cluster
-        constructor specified by `new_cluster` (e.g.
+        constructor specified by `cluster_type` (e.g.
         `n_workers=2`).
 
     Examples
@@ -254,7 +252,7 @@ class Distributed:
     def __init__(self, client=None, cluster_type=None, force_new=False, **cluster_options):
         self._initial_client = global_dask_client()  # Initial state
         self._client = client or "auto"  # Cannot be `None`
-        self.cluster_type = cluster_type or ("cpu" if cuda is None else "cuda")
+        self.cluster_type = cluster_type or ("cuda" if HAS_GPU else "cpu")
         self.cluster_options = cluster_options
         # We can only shut down the cluster in `shutdown`/`__exit__`
         # if we are generating it internally
